@@ -1,10 +1,9 @@
 from tensorflow.keras.applications.mobilenet_v2 import preprocess_input
 from tensorflow.keras.preprocessing.image import img_to_array
 from tensorflow.keras.models import load_model
-#from imutils.video import VideoStream
 import numpy as np
 import argparse
-#import imutils
+import imutils
 import time
 import cv2
 import os
@@ -83,6 +82,9 @@ def get_args():
     ap.add_argument("-m", "--model", type=str,
 	    default="models/helmet_detector.h5",
 	    help="path to trained helmet detector model")
+    ap.add_argument("-o", "--output", 
+        default="file", type=str,
+        help="image output to file or screen")
     ap.add_argument("-c", "--confidence", type=float, default=0.5,
 	    help="minimum probability to filter weak detections")
     args = vars(ap.parse_args())
@@ -93,7 +95,7 @@ def main():
     print('Downloading models ...')
     args = get_args()
     # load our serialized face detector model from disk
-    print("[INFO] loading face detector model...")
+    print("Loading face detector model...")
     prototxtPath = os.path.sep.join([args["face"], "deploy.prototxt"])
     print(f'Path : {prototxtPath}')
     weightsPath = os.path.sep.join([args["face"],
@@ -102,7 +104,7 @@ def main():
     faceNet = cv2.dnn.readNet(prototxtPath, weightsPath)
 
     # load the face mask detector model from disk
-    print("[INFO] loading face mask detector model...")
+    print("Loading helmet detector model...")
     maskNet = load_model(args["model"])
 
     # load the input image from disk, clone it, and grab the image spatial
@@ -116,7 +118,6 @@ def main():
         (104.0, 177.0, 123.0))
 
     # pass the blob through the network and obtain the face detections
-    print("[INFO] computing face detections...")
     faceNet.setInput(blob)
     detections = faceNet.forward()
 
@@ -169,12 +170,15 @@ def main():
             else:
                 cv2.putText(image, "No helmet detected", (startX, startY - 10),
                     cv2.FONT_HERSHEY_SIMPLEX, 0.45, color, 1)
-    # show the output image
-    image = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
-    plt.imshow(image)
-    #plt.show()
-    #cv2.imshow("Output", image)
-    #cv2.waitKey(0)
+    # show the output image depending on output
+    output_file = 'image.jpg'
+    if args["output"] == 'file':
+        print(f'Writing out to {output_file}')
+        cv2.imwrite(output_file, image)
+    else:
+        print(f'Writing out to display')
+        cv2.imshow("Output", image)
+        cv2.waitKey(0)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
